@@ -7,10 +7,10 @@ import argparse
 import os
 import subprocess
 import urllib.request, urllib.error, urllib.parse
-from utils import retrieve_creds
+from . import utils
 import sys
 from shutil import copyfile
-from agent import run_agent
+from .agent import run_agent
 from time import sleep
 
 
@@ -159,7 +159,7 @@ def handle_credentials(account_id, script_full_path, spotinst_agent_path, token)
 
     else:
         # Credentials already exist - retrieve from file
-        creds = retrieve_creds()
+        creds = utils.retrieve_creds()
         token = creds["token"]
         account_id = creds["account_id"]
     os.putenv("SPOTINST_TOKEN", token)
