@@ -2,7 +2,8 @@ from __future__ import absolute_import
 # load credentials
 from builtins import str
 import logging
-from utils import safe_read_simple_url, safe_get_json, retrieve_creds, get_gcp_metadata, get_azure_metadata
+from . import utils
+from .utils import safe_read_simple_url, safe_get_json
 
 """
 This is for Elastic group spotinst-agent specific
@@ -114,7 +115,7 @@ def init__configuration(config, cloud_provider, debug=False):
     instance_details = None
     log = logging.getLogger('spotinst-agent')
 
-    creds = retrieve_creds()
+    creds = utils.retrieve_creds()
     authentication_token = creds["token"]
     account_id = creds["account_id"]
 
@@ -152,7 +153,7 @@ def getGcpInstanceMetadata(locator_url, path_params, log):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
-            response = get_gcp_metadata(locator_url, path_params, log)
+            response = utils.get_gcp_metadata(locator_url, path_params, log)
             response = str(response)
 
         log.debug("found instance id - {}".format(response))
@@ -167,7 +168,7 @@ def getAzureInstanceId(locator_url, log):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
-            response = get_azure_metadata(locator_url, log)
+            response = utils.get_azure_metadata(locator_url, log)
             response = str(response)
 
         else:
